panelData = {
    type = "panel",
    name = CPP.displayName,
    displayName = CPP.Loc.GetString("CPP_MENU_TITLE"),
    author = "fabian96de",
    version = "0.0.4",
    slashCommand = "/cpp-menu",
    registerForRefresh = true,
}

optionsTable = {
    [1] = {
        type = "divider",
        reference = "div1"
    },
    [2] = {
        type = "submenu",
        name = CPP.Loc.GetString("CPP_MENU_LOAD_TITLE"),
        controls = {
            [1] = {
                type = "dropdown",
                name = CPP.Loc.GetString("CPP_MENU_LOAD_SAVED_PROFILES"),
                getFunc = function() return CPP.controls.selectedName end,
                setFunc = function(var) CPP.controls.selectedName = var end,
            },
            [2] = {
                type = "button",
                name = CPP.Loc.GetString("CPP_MENU_LOAD_LOADING"),
                func = function() CPP.LoadProfile(); end,
            },
        },
    },
    [3] = {
        type = "submenu",
        name = CPP.Loc.GetString("CPP_MENU_SAVE_TITLE"),
        controls = {
            [1] = {
                type = "editbox",
                name = CPP.Loc.GetString("CPP_MENU_SAVE_PROFILE_NAME"),
                getFunc = function() return "" end,
                setFunc = function(text) CPP.controls.saveName = text; end,
            },
            [2] = {
                type = "button",
                name = CPP.Loc.GetString("CPP_MENU_SAVE_SAVING"),
                func = function() CPP.SaveProfile(); end,
                warning = CPP.Loc.GetString("CPP_RELOAD_UI"),
            },
        },
    },
    [4] = {
        type = "submenu",
        name = CPP.Loc.GetString("CPP_MENU_DELETE_TITLE"),
        controls = {
            [1] = {
                type = "dropdown",
                name = CPP.Loc.GetString("CPP_MENU_DELETE_SUBMIT"),
                getFunc = function() return CPP.controls.selectedName end,
                setFunc = function(var) CPP.controls.selectedName = var end,
            },
            [2] = {
                type = "button",
                name = CPP.Loc.GetString("CPP_MENU_DELETE_SUBMIT"),
                func = function() CPP.DeleteProfile(CPP.controls.selectedDelName, true); end,
                warning = CPP.Loc.GetString("CPP_RELOAD_UI"),
            },
        },
    },
--    [5] = {
--        type = "submenu",
--        name = "Import/Export",
--        controls = {
--            [1] = {
--                type = "dropdown",
--                name = "temporär gespeicherte Profile",
--                getFunc = function() return CPP.controls.selectedTempName end,
--                setFunc = function(var) CPP.controls.selectedTempName = var end,
--            },
--            [2] = {
--                type = "button",
--                name = CPP.Loc.GetString("CPP_MENU_SAVE_SAVING"),
--                func = function() CPP.SaveTempProfile(); end,
--            },
--            [3] = {
--                type = "dropdown",
--                name = "Profil teilen",
--                getFunc = function() return CPP.controls.selectedShareName end,
--                setFunc = function(var) CPP.controls.selectedShareName = var end,
--            },
--            [4] = {
--                type = "button",
--                name = "Teilen...",
--                func = function() CPP.ShareProfile() end,
--            },
--        },
--    },
}

function CPP.RegisterMenu()
    CPP.ReloadDropdowns();
    local LAM = LibStub("LibAddonMenu-2.0");
    LAM:RegisterAddonPanel(CPP.menu, panelData);
    LAM:RegisterOptionControls(CPP.menu, optionsTable);
end

function CPP.ReloadDropdowns()
    optionsTable[2].controls[1].choices = CPP.GetAllSavedProfile();
    optionsTable[4].controls[1].choices = CPP.GetAllSavedProfile();
--    optionsTable[5].controls[3].choices = CPP.GetAllSavedProfile();
--    optionsTable[5].controls[1].choices = CPP.GetAllSavedProfile(true);
end

function CPP.LoadProfile()
    if CPP.respecRunning then
        ZO_Dialogs_ShowDialog("CPP_RESPEC_IS_RUNNING");
    else
        SetChampionIsInRespecMode(true);

        if IsChampionRespecNeeded() then
            ZO_Dialogs_ShowDialog("CPP_CONFIRM_CP_WITH_GOLD", nil, { mainTextParams = { GetChampionRespecCost(), ZO_Currency_GetPlatformFormattedGoldIcon() } });
        else
            ZO_Dialogs_ShowDialog("CPP_CONFIRM_CP_WITHOUT_GOLD");
        end
    end
end

function CPP.SaveTempProfile()
    local profile = "";

    for k, v in pairs(CPP.varsTemp.profiles) do
        if (string.lower(v.name) == string.lower(CPP.controls.selectedTempName)) then
            profile = CPP.varsTemp.profiles[k];
        end
    end

    if (profile == "") then
        CPP.Notify(CPP.Loc.GetString("CPP_PROFILE_UNVALID"));
        return;
    end

    if CPP.IsNameValid(profile.name) then
        table.insert(CPP.vars.profiles, { name = profile.name, hash = profile.hash });
    end
end

function CPP.SaveProfile()
    local success, err = CPP.IsNameValid(CPP.controls.saveName);
    if (success) then
        local n = CPP.controls.saveName;
        local h = CPP.BuildHash();
        table.insert(CPP.vars.profiles, { name = n, hash = h });

        CPP.controls.isReloading = true;
        ReloadUI();
        CPP.Notify(CPP.Loc.GetString("CPP_PROFILE_SAVE_SUCCESS"));
    else
        CPP.Notify(CPP.Loc.GetString(err));
    end
end

function CPP.ShareProfile()
    local profile = "";

    for k, v in pairs(CPP.vars.profiles) do
        if (string.lower(v.name) == string.lower(CPP.controls.selectedShareName)) then
            profile = CPP.vars.profiles[k];
        end
    end

    if (profile == "") then
        CPP.Notify(CPP.Loc.GetString("CPP_PROFILE_UNVALID"));
        return;
    end

    local n = profile.name;
    local h = profile.hash;

    ZO_ChatWindowTextEntryEditBox:SetText("[CPP]:" .. n .. ":" .. h);
end
