function split(inputstr, sep)
    if sep == nil then
        sep = "%s"
    end
    local t = {}; i = 1
    for str in string.gmatch(inputstr, "([^" .. sep .. "]+)") do
        t[i] = str
        i = i + 1
    end
    return t
end

function CPP.Notify(message)
    local params = CENTER_SCREEN_ANNOUNCE:CreateMessageParams(CSA_CATEGORY_MAJOR_TEXT, SOUNDS.TELVAR_MULTIPLIERMAX);
    params:SetCSAType(CENTER_SCREEN_ANNOUNCE_TYPE_RAID_TRIAL);
    params:SetText(message);
    CENTER_SCREEN_ANNOUNCE:AddMessageWithParams(params);
end

function CPP.GetAllSavedProfile(temp)
    local t = {}
    local n = 0;

    local profiles = {};

    if (temp ~= nil and temp == true) then
        profiles = CPP.varsTemp.profiles;
    else
        profiles = CPP.vars.profiles;
    end

    for k, v in pairs(profiles) do
        table.insert(t, v.name);
    end

    if (table.getn(t) > 0) then
        if (temp ~= nil and temp == true) then
            CPP.controls.selectedTempName = t[1];
        else
            CPP.controls.selectedName = t[1];
            CPP.controls.selectedShareName = t[1];
            CPP.controls.selectedDelName = t[1];
        end
    end

    return t;
end

function CPP.GetProfileByName(name)
    local profile = "";

    for k, v in pairs(CPP.vars.profiles) do
        if (string.lower(v.name) == string.lower(name)) then
            profile = CPP.vars.profiles[k];
            profile.id = k;
        end
    end

    if (profile == "") then
        return;
    end

    return profile;
end

function CPP.DeleteProfile(name, reload)
    local profile = CPP.GetProfileByName(name);
    if profile ~= nil then
        CPP.vars.profiles[profile.id] = nil;
        CPP.Notify(CPP.Loc.GetString("CPP_DELETE_SUCCESSFULL"));
        if reload then
            ReloadUI();
        end
    else
        CPP.Notify(CPP.Loc.GetString("CPP_ERR_NO_PROFILE"));
    end
end

function CPP.DeleteAllProfiles()
    for k, v in pairs(CPP.vars.profiles) do
        CPP.DeleteProfile(v.name, false);
    end

    ReloadUI();
end

function CPP.DeleteAllTempProfiles()
    for k, v in pairs(CPP.tempSaved.profiles) do
        CPP.tempSaved.profiles[k] = nil;
    end

    ReloadUI();
end

function CPP.IsNameValid(name)
    if (name == "") then
        return false, CPP.Loc.GetString("CPP_ERR_NO_NAME");
    end

    for k, v in pairs(CPP.vars.profiles) do
        if (v.name == name) then
            return false, CPP.Loc.GetString("CPP_ERR_DUPLICATE");
        end
    end

    return true, "";
end

function CPP.IsHashValid(hash)
    local skills = split(hash, "$");

    for k, v in pairs(skills) do
        skills[k] = split(v, "&");
    end

    for i = 1, 9 do
        for j = 1, 4 do
            if (skills[i][j] == nil or tonumber(skills[i][j]) == nil) then
                return false;
            end
        end
    end

    return true;
end

function CPP.Loc.GetString(key)
    local text = CPP.Loc[key];

    if text == nil or text == string.char() then
        return key;
    end

    return text;
end

function CPP.BuildHash()
    local pending = CPP.PendingChampionPointsSelected();
    local hash = "";
    for disciplineIndex = 1, 9 do
        for skillIndex = 1, 4 do
            local pointsSpent = 0;
            local skillUnlockLevel = GetChampionSkillUnlockLevel(disciplineIndex, skillIndex);

            if pending then
                pointsSpent = GetNumPendingChampionPoints(disciplineIndex, skillIndex);
            else
                pointsSpent = GetNumPointsSpentOnChampionSkill(disciplineIndex, skillIndex);
            end

            if not skillUnlockLevel then
                if skillIndex < 4 then
                    hash = hash .. pointsSpent .. "&";
                else
                    hash = hash .. pointsSpent;
                end
            end
        end
        hash = hash .. "$";
    end

    return hash;
end

function CPP.PendingChampionPointsSelected()
    for i = 1, 9 do
        for j = 1, 4 do
            if (GetNumPendingChampionPoints(i, j) > 0) then
                return true;
            end
        end
    end
    return false;
end
